==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="97"/>
        <source>File Information</source>
        <translation>Informacje o pliku</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Właściciel:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Grupa:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Uprawnienia:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Utworzony:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Uwaga: Jeśli uprawnienia pliku zostały ostatnio zmienione, to czasz utworzenia pliku oraz czas jego ostatniej modyfikacji mogą się różnić. </translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Zmodyfikowany:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>Typ MIME:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="140"/>
        <source>Edit Shortcut</source>
        <translation>Edytuj skrót</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Katalog roboczy:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Powiadamianie przy uruchomieniu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Polecenie:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Uruchom w terminalu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Brak ikony</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="61"/>
        <source>---Calculating---</source>
        <translatorcomment>moze szacowanie bedzie lepsze?</translatorcomment>
        <translation>---Obliczanie---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read/Write</source>
        <translation>odczyt/zapis</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Read Only</source>
        <translation>Tylko do odczytu</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>Write Only</source>
        <translation>Tylko do zapisu</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="73"/>
        <source>No Access</source>
        <translation>Brak dostępu</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>XDG Shortcut</source>
        <translation>Skrót XDG</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="79"/>
        <source>Binary</source>
        <translation>Plik binarny</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="81"/>
        <source>Hidden %1</source>
        <translation>Ukryty %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="126"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Save Application File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="249"/>
        <source>Application Registrations (*.desktop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="290"/>
        <source>Select a binary</source>
        <translation>Wybierz plik binarny</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="293"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Nieprawidłowy wybór: To nie jest prawidłowy plik binarny</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="305"/>
        <source>Select a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Select an icon</source>
        <translation>Wybierz ikonę</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="318"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Obrazy (%1);; Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source> Folders: </source>
        <translation> Katalogi: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <location filename="../MainUI.cpp" line="343"/>
        <source>Files: </source>
        <translation>Pliki: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="343"/>
        <source>  Calculating...</source>
        <translation>  Szacowanie...</translation>
    </message>
</context>
</TS>

==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-fileinfo/i18n/l-fileinfo_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <location filename="../MainUI.ui" line="24"/>
        <location filename="../MainUI.cpp" line="96"/>
        <source>File Information</source>
        <translation>Informacje o pliku</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="56"/>
        <source>Owner:</source>
        <translation>Właściciel:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="73"/>
        <source>Group:</source>
        <translation>Grupa:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Permissions:</source>
        <translation>Uprawnienia:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="104"/>
        <source>Created:</source>
        <translation>Utworzony:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="111"/>
        <source>Note: The time a file was created might be more recent than the time modified if the file permissions were changed recently.</source>
        <translation>Uwaga: Jeśli uprawnienia pliku zostały ostatnio zmienione, wtedy czas utworzenia pliku oraz czas jego ostatniej modyfikacji mogą się różnić.</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Last Modified:</source>
        <translation>Zmodyfikowany:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="131"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>MimeType:</source>
        <translation>Typ MIME:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="185"/>
        <source>File Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="216"/>
        <location filename="../MainUI.cpp" line="139"/>
        <source>Edit Shortcut</source>
        <translation>Edytuj skrót</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="239"/>
        <source>Working Dir:</source>
        <translation>Katalog roboczy:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="246"/>
        <source>Use startup notification</source>
        <translation>Powiadamianie przy uruchomieniu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="260"/>
        <source>Icon:</source>
        <translation>Ikona:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="267"/>
        <source>Command:</source>
        <translation>Polecenie:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="274"/>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="284"/>
        <source>Run in terminal</source>
        <translation>Uruchom w terminalu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="336"/>
        <source>No Icon</source>
        <translation>Brak ikony</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="405"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="60"/>
        <source>---Calculating---</source>
        <translatorcomment>moze szacowanie bedzie lepsze?</translatorcomment>
        <translation>---Obliczanie---</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="69"/>
        <source>Read/Write</source>
        <translation>odczyt/zapis</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="70"/>
        <source>Read Only</source>
        <translation>Tylko do odczytu</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="71"/>
        <source>Write Only</source>
        <translation>Tylko do zapisu</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="72"/>
        <source>No Access</source>
        <translation>Brak dostępu</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="76"/>
        <source>XDG Shortcut</source>
        <translation>Skrót XDG</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="77"/>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="78"/>
        <source>Binary</source>
        <translation>Plik binarny</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="80"/>
        <source>Hidden %1</source>
        <translation>Ukryty %1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="125"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Save Application File</source>
        <translation>Zapisz plik aplikacji</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="247"/>
        <source>Application Registrations (*.desktop)</source>
        <translation>Rejestracje aplikacji (*.desktop)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="288"/>
        <source>Select a binary</source>
        <translation>Wybierz plik binarny</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="291"/>
        <source>Invalid selection: Not a valid executable</source>
        <translation>Nieprawidłowy wybór: To nie jest prawidłowy plik binarny</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="303"/>
        <source>Select a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Select an icon</source>
        <translation>Wybierz ikonę</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="316"/>
        <source>Images (%1);; All Files (*)</source>
        <translation>Obrazy (%1);; Wszystkie pliki (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source> Folders: </source>
        <translation> Katalogi: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="339"/>
        <location filename="../MainUI.cpp" line="341"/>
        <source>Files: </source>
        <translation>Pliki: </translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="341"/>
        <source>  Calculating...</source>
        <translation>  Szacowanie...</translation>
    </message>
</context>
</TS>
